@@ -8,7 +8,7 @@ from notejob.center.datas.model.cron_infos import CronInfos
 from notejob.center.datas.model.job_log import JobLog
 from notejob.center.datas.model.job_log_items import JobLogItems
 
-from .init import api
+from .core import api
 
 '''
 添加（更新）定时
